@@ -310,8 +310,12 @@ def from_grpc(operation, operations_stub, result_type, grpc_metadata=None, **kwa
         ~.api_core.operation.Operation: The operation future to track the given
             operation.
     """
-    refresh = functools.partial(_refresh_grpc, operations_stub, operation.name, metadata=grpc_metadata)
-    cancel = functools.partial(_cancel_grpc, operations_stub, operation.name, metadata=grpc_metadata)
+    refresh = functools.partial(
+        _refresh_grpc, operations_stub, operation.name, metadata=grpc_metadata
+    )
+    cancel = functools.partial(
+        _cancel_grpc, operations_stub, operation.name, metadata=grpc_metadata
+    )
     return Operation(operation, refresh, cancel, result_type, **kwargs)
 
 
@@ -338,6 +342,10 @@ def from_gapic(operation, operations_client, result_type, grpc_metadata=None, **
         ~.api_core.operation.Operation: The operation future to track the given
             operation.
     """
-    refresh = functools.partial(operations_client.get_operation, operation.name, metadata=grpc_metadata)
-    cancel = functools.partial(operations_client.cancel_operation, operation.name, metadata=grpc_metadata)
+    refresh = functools.partial(
+        operations_client.get_operation, operation.name, metadata=grpc_metadata
+    )
+    cancel = functools.partial(
+        operations_client.cancel_operation, operation.name, metadata=grpc_metadata
+    )
     return Operation(operation, refresh, cancel, result_type, **kwargs)
